<?php
use function Convert\bytes;

/*DESCRIPTION: inclus les variables habituelles pour la gestion d'un block et vérifie les droits d'accès
 *APRES l'inclusion du common_block les variables suivantes sont créées:
 *PHP:
 *      $dbconnection objet PDO de connexion à la DB
 *      $webplugin_path chemin d'accès au web plugin de repport (default: /usr/local/esia/public_html/plugin/report/
 *      $lang tableau associatif avec les variables de langue
 *      $action l'action passé dans l'url ou 'view'
 *      $gendate tableau associatif reprenant les paramètres global avec les clés suivantes:
 *               ['start']  timestamps de début
 *               ['end']    timestamps de fin
 *               ['interval'] interval en nombre de jour au format php. voir %a par rapport à la date de début  https://www.php.net/manual/fr/dateinterval.format.php
 *      $block les données du block en DB
 *      $parameters un tableau associatif reprenant les paramètres du block
 * SMARTY
 *      $block les informations du block
 *      $parameter les parametres du block (JSON)
 *      $action l'action passé dans l'url ou 'view'
 */
require_once '/usr/local/esia/public_html/plugin/report/report.conf.php';
require_once REPORT_COMMON_BLOCK;

$template_path = $path . '/plugin/report/blocks/templates/';

if($action=="generate")
{
	$param = $block['parameters'];

	if($param['type']=="service")
	{			
		if($param['forme']=="donut")
		{
			if($param['onegraph']==true)
			{
				getOneGraphService($dbconnection,$end,$interval,$smarty,$param,$lang,$param['forme']);	
			}
			else
			{
				$donut_array = array();
				foreach ($param['nodeid'] as $node)
				{			
					$listservice = Model_esia::getServices($dbconnection,$node);
					foreach ($param['serviceid'] as $idService)
					{
						$name=SearchIfContainService($listservice,$idService);			
						if($name!=false)
						{
							$common_name = Model_esia::getCommonName($lang, $name['service_name'], $name['plugin_name']);
							$result=Model_esia::getTimeErrorAvailability($dbconnection,$node,$idService,$end,$interval);
							$result = eliminateErreurAvaibility($result,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);

							$remaining = 100-$result['ok']['percent'];
							$availability = number_format($result['ok']['percent'],3);
							$not_availability = number_format($remaining,3);
							
							$result['value'] = array('OK' => $availability, 'NOT' => $not_availability);
							$result['title'] = $name['device_name']." : ".$common_name;
							$result['rand'] = rand();
							array_push($donut_array,$result);
																	
						}
					}
					$smarty->assign('donuts',$donut_array);
				}
				var_dump($donut_array);
			}
		}
		elseif($param['forme']=="tab2")
		{
		    
			$elementTab = array();
			$temp= array();
			foreach ($param['nodeid'] as $node) 
			{				
			    try  
			    {
    				$infonode=Model_esia::InstanceNode($dbconnection,$node);				
    				$listservice = Model_esia::getServices($dbconnection,$node);
    				foreach ($param['serviceid'] as $idService)
    				{
    					$name=SearchIfContainService($listservice,$idService);
    					if($name!=false)
    					{				
    						$common_name = Model_esia::getCommonName($lang, $name['service_name'], $name['plugin_name']);
    						$result=Model_esia::getTimeErrorAvailability($dbconnection,$node,$idService,$end,$interval);		
    						$result = eliminateErreurAvaibility($result,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);				

    						$elementTab[] = array('groupname'=>$infonode->getGroup(),
												  'ip'=>$infonode->getIPAddress(),
												  'device_type'=>$name['device_type'],
												  'device_name'=>$name['device_name'],
												  'common_name'=>$common_name,
												  'percent'=>number_format($result['ok']['percent'], 3)
												  );
    					}
    				}
			    }
			    catch(Exception $e)
			    {
			        
			    }
			}		
			$smarty->assign('tabs',$elementTab);
			
		}
		elseif($param['forme']=="graph")
		{
			if($param['onegraph']==true)
			{
				getOneGraphService($dbconnection,$end,$interval,$smarty,$param,$lang,$param['forme']);	
				
			}
			else
			{
				$graphs = array();
				foreach ($param['nodeid'] as $node)
				{
					$listservice = Model_esia::getServices($dbconnection,$node);
					foreach ($param['serviceid'] as $idService)
					{
						$name=SearchIfContainService($listservice,$idService);
						if($name!=false)
						{
							$common_name = Model_esia::getCommonName($lang, $name['service_name'], $name['plugin_name']);
							$pourcent = getAvailabilityList($dbconnection,$node,$idService,$end,$interval);
							if($pourcent!=null)
							{
								$parsed = array();
								foreach ($pourcent as $key => $valpourcent)
								{
									$parsed[parseAvailabilityDate($key,$interval)] = $valpourcent;
								}
								$json = GetGraphJson($parsed,$idService,$lang,$interval);
								$graphs[] = array('title' => $name['device_name']." : ".$common_name,
												'data' => $json,
												'rand' => rand(),
												'interval' => $interval
												);
							}
						}
					}
				}
				
				$smarty->assign('graphs',$graphs);
			}
		}
		elseif ($param['forme']=="abre")
		{	
			if($param['onegraph']==true)
			{
				getOneGraphService($dbconnection,$end,$interval,$smarty,$param,$lang,$param['forme']);	
			}
			else
			{
				$abre_array = array();
				foreach ($param['nodeid'] as $node) 
				{
					$listservice = Model_esia::getServices($dbconnection,$node);
					foreach ($param['serviceid'] as $idService)
					{
						$name=SearchIfContainService($listservice,$idService);
						if($name!=false)
						{
							$common_name = Model_esia::getCommonName($lang, $name['service_name'], $name['plugin_name']);
							$result=Model_esia::getTimeErrorAvailability($dbconnection,$node,$idService,$end,$interval);
							$result = eliminateErreurAvaibility($result,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);
							$state= returnState($result['ok']['percent'],$param);
							$result['state'] = $state;
							$result['title'] = $name['device_name']." : ".$common_name;
							$result['rand'] = rand();
							
							array_push($abre_array,$result);
						}
					}
				}
				$smarty->assign('abres',$abre_array);
			}
		}
		elseif($param['forme']=="token" || $param['forme']=="rectangle")
		{
			if ($param['forme']=="token")
			{
				$radius="50%";
			}
			else
			{
				$radius="5px";
			}
			
			if($param['onegraph']==true)
			{
				getOneGraphService($dbconnection,$end,$interval,$smarty,$param,$lang,$param['forme']);	
			}
			else
			{
				$token_array = array();
				foreach ($param['nodeid'] as $node)
				{
					$listservice = Model_esia::getServices($dbconnection,$node);
					foreach ($param['serviceid'] as $idService)
					{
						$name=SearchIfContainService($listservice,$idService);
						if($name!=false)
						{
							$common_name = Model_esia::getCommonName($lang, $name['service_name'], $name['plugin_name']);
							$result=Model_esia::getTimeErrorAvailability($dbconnection,$node,$idService,$end,$interval);
							$result = eliminateErreurAvaibility($result,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);
							$state=returnState($result['ok']['percent'],$param);
							$result['title'] = $name['device_name']." : ".$common_name;
							$result['state'] = $state;
							$result['radius'] = $radius;
							array_push($token_array,$result);
						}
					}
				}
				$smarty->assign('tokens',$token_array);
			}
		}
		elseif($param['forme']=="gauge")
		{
			if($param['onegraph']==true)
			{
				getOneGraphService($dbconnection,$end,$interval,$smarty,$param,$lang,$param['forme']);	
			}
			else
			{
				$gauge_array = array();
				foreach ($param['nodeid'] as $node)
				{			
					$listservice = Model_esia::getServices($dbconnection,$node);				
					foreach ($param['serviceid'] as $idService)
					{
						$name=SearchIfContainService($listservice,$idService);
						if($name!=false)
						{
							$common_name = Model_esia::getCommonName($lang, $name['service_name'], $name['plugin_name']);
							$result=Model_esia::getTimeErrorAvailability($dbconnection,$node,$idService,$end,$interval);		
							$result = eliminateErreurAvaibility($result,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);
							$result['title'] = $name['device_name']." : ".$common_name;
							$result['rand'] = rand();
							$result['value'] = number_format($result['ok']['percent'],2);
							
							array_push($gauge_array,$result);
							
						}
					}				
				}
				$smarty->assign('gauges',$gauge_array);
			}
		}
		elseif($param['forme']=='graphCol')
		{
		    $elementTab = array();
		    foreach ($param['nodeid'] as $node)
		    {
		        try
		        {
		            $infonode=Model_esia::InstanceNode($dbconnection,$node);
		            $listservice = Model_esia::getServices($dbconnection,$node);
		            foreach ($param['serviceid'] as $idService)
		            {
		                $name=SearchIfContainService($listservice,$idService);
		                if($name!=false)
		                {
		                    $common_name = Model_esia::getCommonName($lang, $name['service_name'], $name['plugin_name']);
		                    $result=Model_esia::getTimeErrorAvailability($dbconnection,$node,$idService,$end,$interval);
		                    $result = eliminateErreurAvaibility($result,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);
		                    $elementTab[$infonode->getName().' - '.$name['service_name'].$idService] = array('name'=>$infonode->getName()."-".$common_name,'percent'=>$result['ok']['percent']);
							
		                }
		            }
		        }
		        catch(Exception $e)
		        {
		            
		        }
		    }
		    ksort($elementTab);
		    $c3data=array("data1");
		    $c3headder=array();
		    foreach($elementTab as $line)
		    {
		        $c3data[]=$line['percent'];
		        $c3headder[]=$line['name'];
		    }
			$smarty->assign('rand',rand());
			$smarty->assign('c3data',json_encode($c3data));
			$smarty->assign('c3headder',json_encode($c3headder));
		   
		}
	}
	elseif($param['type']=="noeud" || $param['type']=="groupenoeud")
	{
		// Info : Pour chaque cas ou la representation se fait en un seul schema, le code passera dans le if 'graph'
		$tab_id_node = array();		
		
		if(isset($user) && is_null($user)==false)
		{
			$tab_id_node=nodeOrGroupNode($dbconnection,$param,$user->getId());
		}
		else
		{
			$report_user = Model_Report::getOwnerCanevas($dbconnection,$query['include_canevas_id']);
			$iduser = $report_user;
			$tab_id_node=nodeOrGroupNode($dbconnection,$param,$iduser[0]);
		}	
		$tab_node_service = array();
		foreach ($tab_id_node as &$node)
		{
			$listservice = Model_esia::getServices($dbconnection,$node['id']);
			if(!empty($param['plugin']))
			{
				foreach($listservice as $ser)
				{
					if(in_array($ser['plugin_id'], $param['plugin']))
					{
						$node['services'][]=$ser;
					}
				}
			}
			else 
			{
				$node['services']=$listservice;
			}
		}
        if($param['forme']=="tab2")
		{		
			$elementTab = array();
			$temp= array();
			
			foreach ($tab_id_node as $node)
			{
				$resultat= StateAvailability($dbconnection,$node['services'],$node['id'],$end,$interval);
				$resultat = eliminateErreurAvaibility($resultat,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);
				$listservice=$node['services'][0];
				$elementTab[] = array('groupname'=>$node['parent'],
									  'ip'=>$node['ip'],
									  'device_type'=>$listservice['device_type'],
									  'device_name'=>$node['name'],
					'percent'=> number_format($resultat['ok']['percent'],3));
			}
			$smarty->assign('tabs',$elementTab);

		}
		elseif($param['forme']=='graphCol')
		{
		    $elementTab = array();
		    foreach ($tab_id_node as $node)
		    {
		        try
		        {
                    if(!empty($listservice))
                    {
                    	$resultat= StateAvailability($dbconnection,$node['services'],$node['id'],$end,$interval);
		                $resultat = eliminateErreurAvaibility($resultat,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);
                        $avai = $resultat['ok']['percent'];
                        if($avai=='NAN')
                        {
                            $avai=0;
                        }
                    }
                    else
                    {
                        $avai=0;
                    }
		            $elementTab[$node['name']] = array('name'=>$node['name'],'percent'=>round($avai,2));
		        }
		        catch(Exception $e)
		        {
		            
		        }
		    }
		    ksort($elementTab);
		    $c3data=array("data1");
		    $c3headder=array();
		    foreach($elementTab as $line)
		    {
		        $c3data[]= $line['percent'];
		        $c3headder[]=$line['name'];
		    }
		    $smarty->assign('rand',rand());
			$smarty->assign('c3data',json_encode($c3data));
			$smarty->assign('c3headder',json_encode($c3headder));
		}
		elseif($param['forme']=="graph")
		{	
			$shape_array = array();
			if($param['onegraph']=='on') //toujours faux pour couper la fonction
			{
				$listname  = array();
				$json_total = array();
				foreach ($tab_id_node as $node)
				{
					$jsontable=getNodeServicesAvailabilities($dbconnection,$node,$node['services'],$end,$interval);
					
					$mt = microtime(true);
					$id = ($mt*10000)%100000;
					$id = $node['id'].$id;
					$services=$services[0];					
					$tab = array();
					$newtab=array();
					$numberofplugin = 0;
					if($param['type']=="noeud")
					{
						array_push($listname , $services['device_name']);					
						////////////////////////////////////////////
						foreach($jsontable as $key => $value)
						{
							$newcmpt = 0;
							if($key!="x")
							{
								foreach($value as $val)
								{
									$tab[$newcmpt]=$val+$tab[$newcmpt];
									$newcmpt++;
								}
								$numberofplugin++;
							}
						}
						$newtab['x']=$jsontable['x'];
						foreach($tab as $key => $val)
						{
							$tab[$key]=$val/$numberofplugin;
						}
						$newtab[$services['device_name']]=$tab;
						$json_total = $json_total+$newtab;
						////////////////////////////////////////////
					}
					else
					{					
						foreach ($param['groupnodeid'] as $groupnode)
						{	
													
							$query=Model_esia::getGroupDeviceIn($dbconnection,$groupnode);
                            
							$query=$query[0];
                            if(!in_array($query['name'], $listname))
                            {
							    array_push($listname , $query['name']);
                            }
						}			
                        $tab = array();		
						////////////////////////////////////////////
						foreach($jsontable as $key => $value)
						{
							$newcmpt = 0;
							if($key!="x")
							{
								foreach($value as $val)
								{
									$tab[$newcmpt]=$val+$tab[$newcmpt];
									$newcmpt++;
								}
								$numberofplugin++;
							}
						}
						//$newtab['x']=$jsontable['x'];
						foreach($tab as $key => $val)
						{
							$tab[$key]=$val/$numberofplugin;
						}
						//$newtab[]=$tab;
                        $json_total[$node['parent']] = $tab;
					}	
				}
                $json_total['x']=$jsontable['x'];
				$json_total = json_encode($json_total);		
								
				$arr['title'] = implode(" & ",$listname );
				$arr['data'] = $json_total;
				$arr['interval'] = $interval;
				$arr['rand'] = rand();
				array_push($shape_array,$arr);
				
			}
			else
			{
				foreach ($tab_id_node as $node)
				{
					$arr = array();
					$jsontable=getNodeServicesAvailabilities($dbconnection,$node,$node['services'],$end,$interval);
					
					$arr['data'] = json_encode($jsontable);
					$arr['interval'] = $interval;
					$arr['rand'] = rand();
					if($param['type']=="groupenoeud")
					{
						$arr['title'] = $node['parent'].' - '.$node['name'];	
					}
					else
					{
						$arr['title'] = $node['name'];
					}
					array_push($shape_array,$arr);
				}
				
			}
			$smarty->assign('graphs', $shape_array);
			
		}
		elseif($param['forme']=="token" || $param['forme']=="rectangle" || $param['forme']=="abre")
		{
			$shape_array = array();
			if ($param['forme']=="token")
			{
				$radius="50%";
			}
			else
			{
				$radius="5px";
			}
            $globalavaibatily=0;
            foreach ($tab_id_node as $node)
			{				
                $name="";    					
                if($node['parent']!=null || $param['type']=="groupenoeud")
                {
                    $name=$node['parent'].' - ';
                }
                $name .= $node['name'];


                if(!empty($listservice))
                {
                		$resultat=StateAvailability($dbconnection,$node['services'],$node['id'],$end,$interval);
					    $resultat = eliminateErreurAvaibility($resultat,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);
					    $state=returnState($resultat['ok']['percent'],$param);
					    $globalavaibatily = $globalavaibatily + $resultat['ok']['percent'];
                        $list_show[$name]=array('id'=> $node['id'],'name'=>$name,'state'=>$state);
                }
                else
                {
                    $list_show[$name]=array('id'=> $node['id'],'name'=>$name,'state'=>4);
                }
            }
            if($param['mergedata']=='on')
            {
                $size = count($list_show);
                $globalavaibatily= round($globalavaibatily/$size,2);
                $state=returnState($globalavaibatily,$param);
                $list_show=array();
                $list_show['global']=array('id'=>'0','name'=>'global','state'=>$state);
            }
            else
            {
                ksort($list_show);
            }
            foreach($list_show as $line)
            {
				$arr = array();
				$arr['title'] = $line['name'];
				$arr['rand'] = rand();
				$arr['radius'] = $radius;
				$arr['state'] = $line['state'];
				array_push($shape_array,$arr);
            }
			switch ($param['forme'])
				{
					case 'token':
					case 'rectangle':
						$smarty->assign('tokens',$shape_array);
						break;
			
					case 'abre':
						$smarty->assign('abres',$shape_array);
						break;
				}
		}
		elseif($param['forme']=="gauge" || $param['forme']=="donut")
		{
			$shape_array = array();
                $list_show = array();
                $globalavaibatily=0;
				foreach ($tab_id_node as $node)
				{
                    $name="";    					
					if($node['parent']!=null || $param['type']=="groupenoeud")
					{
                        $name=$node['parent'].' - ';
					}
                    $name .= $node['name'];
                    if(!empty($listservice))
                    {
                    	$result= StateAvailability($dbconnection,$node['services'],$node['id'],$end,$interval);
					    $result = eliminateErreurAvaibility($result,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);
                        
                        $list_show[$name]=array('id'=> $node['id'],'name'=>$name,'data'=>$result);
                        $globalavaibatily = $globalavaibatily + $result['ok']['percent'];
                    }
                    else
                    {
                        $list_show[$name]=array('id'=> $node['id'],'name'=>$name,'data'=>'No Service found');
                    }
				}
                if($param['mergedata']=='on')
                {
                    $size = count($list_show);
                    $globalavaibatily= round($globalavaibatily/$size,2);
                    $list_show=array();
                    $list_show['global']=array('id'=>'0','name'=>'global','data'=>array('ok'=>array('percent'=>$globalavaibatily)));
                }
                else
                {
                    ksort($list_show);
                }
				
                foreach($list_show as $line)
                {
					$arr = array();
					$arr['title'] = $line['name'];
					$arr['rand'] = rand();
					if($param['forme'] == 'donut')
					{
						$remaining = 100-$result['ok']['percent'];
						$availability = number_format($result['ok']['percent'],2);
						$not_availability = number_format($remaining,2);
							
						$arr['value'] = array('OK' => $availability, 'NOT' => $not_availability);
					}
					else
					{
						$arr['value'] = number_format($result['ok']['percent'],2);
					}
					array_push($shape_array,$arr);
                }
				if($param['forme'] == 'donut')
				{
					$smarty->assign('donuts',$shape_array);
				}
				else
				{
					$smarty->assign('gauges',$shape_array);
				}
			}
	}		
	$smarty->display($template_path."availability.html");
}
elseif($action=="update")
{
	$parameters = $block['parameters'];
	
	if(!empty($_POST['blockid']))
	{
		try
		{
			// Traite les données post pour le style du titre et de la description
			$block = getPostDefaultParams($block, $_POST);
			$parameters = $block['parameters'];
			// Traitement des variable POST

			// Service & Noeud
			if($parameters['type']=='service')
			{
				$parameters['nodeid']=$_POST['nodes'];
				$parameters['serviceid']=$_POST['services'];
			}
			elseif ($parameters['type']=='noeud')
			{
				$parameters['nodeid']=$_POST['nodes'];
			}
			else
			{
				$parameters['groupnodeid']=$_POST['groupnodes'];
				$parameters['plugin'] = $_POST['plugins'];
			}
			
			// Seuil de Warning et Critical
			$parameters['SeuilCritical']=$_POST['SeuilCritical'];
			$parameters['SeuilWarning']=$_POST['SeuilWarning'];
	
			// Seuil de Warning et Critical
			if( empty($_POST['calcunknown']) )	$_POST['calcunknown'] = 'none';
			if( empty($_POST['calcwarning']) )	$_POST['calcwarning'] = 'none';
			if( empty($_POST['calccritical']) )	$_POST['calccritical'] = 'none';
			if( empty($_POST['mergedata']) )	$_POST['mergedata'] = 'none';
			$parameters['mergedata'] = $_POST['mergedata'];
			$parameters['calcunknown']=$_POST['calcunknown'];
			$parameters['calcwarning']=$_POST['calcwarning'];
			$parameters['calccritical']=$_POST['calccritical'];
			
			// Affichage colonne
			$parameters['affiche_type']=$_POST['type'];
			$parameters['affiche_ip']=$_POST['add_ip'];
			
			// Forme
			$parameters['forme']=$_POST['forme'];
			
			// Une representation ou plusieur
			$parameters['onegraph']=$_POST['onegraph'];
			
			$paramSave = json_encode($parameters);

			$query=Model_Report::getReportIncludeBlock($dbconnection,$_POST['blockid']);
			$query= $query[0];
			
			$query=Model_Report::getReportIncludeBlock($dbconnection,$_POST['blockid']);
			$query= $query[0];
			
			Model_Report::UpdtReportIncludeBlock($dbconnection,$_POST['blockid'],$query['include_block_id'],$query['include_canevas_id'],$query['include_position'],$paramSave);
			$smarty->assign('l_success',$lang['UPDATE_DASHBOARD_SUCCESS']);
			
			if($parameters['calcunknown']='none' && $parameters['calcwarning']== 'none' && $parameters['calccritical']=='none'){
				$smarty->assign('l_warning',$lang['REPORT_AVA_UNCHECKED_ALLBOXES']);
				$smarty->assign('l_success',$lang['UPDATE_REPORT_SUCCESS']);
			}
			else{
				$smarty->assign('l_success',$lang['UPDATE_REPORT_SUCCESS']);
			}
		}
		catch (EsiaDbException $e)
		{
			$smarty->assign('l_error',$e->getMessage());
		}
		catch (Exception $e)
		{
			$smarty->assign('l_error',$e->getMessage());
		}
	}

	$listnode = array();
	//Récupération des services
	if($parameters['type']=="service")
	{
		if(!empty($parameters['serviceid']))
		{
			$services = Model_esia::getServices($dbconnection,null,$parameters['serviceid']);
			foreach($services as $ser)
			{
				if(!in_array($ser['device_id'],$listnode))
					$listnode[]=$ser['device_id'];
			}
			foreach($services as $ser)
			{
				$listservice[]=$ser['id'];
			}
		}
		$smarty->assign('serviceid',$listservice);
	
		$nodes = Model_esia::getNodeList($dbconnection,$user->getId(),null,Model_esia::NODE_INSTANCE);
		$list=array();

		foreach($nodes as $node)
		{
			$selected='no';
			if(in_array($node->getId(),$listnode))
			{
				$selected='yes';
			}
			$list[]=array('id'=>$node->getId(),
					'name'=>$node->getGroup().'>'.$node->getName(),
					'selected'=>$selected			
			);
		}
	}
	elseif($parameters['type']=="noeud")
	{
		//Récupération des noeuds
		$nodes = Model_esia::getNodeList($dbconnection,$user->getId(),null,Model_esia::NODE_INSTANCE);
		$list=array();
		foreach($nodes as $node)
		{
			$selected='no';
			if(in_array($node->getId(),$parameters['nodeid']))
			{
				$selected='yes';
			}
			$list[]=array('id'=>$node->getId(),
					'name'=>$node->getGroup().'>'.$node->getName(),
					'selected'=>$selected
						
			);
		}
	}
	else
	{
		$arr = Model_esia::getGroupDevice($dbconnection,$groupnode,$user->getId());
		$list_group_node =array();
		foreach($arr as $group)
		{
			$selected='no';
			if(in_array($group['id'],$parameters['groupnodeid']))
			{
				$selected='yes';
			}
			$list_group_node[]=array('id'=>$group['id'],'name'=>$group['fullpath'],'selected'=>$selected);
		}
		$smarty->assign('adm_list_group_node', $list_group_node);
	}

	// Recupération des styles
	assignCommonStyles($smarty, $parameters);
	
	$smarty->assign('param', $parameters);
	$smarty->assign('adm_list_node', $list);
	$smarty->assign('action','update');
	$smarty->display($template_path.'availability.html');
}
elseif($action=="plugin")
{
	$parameters = $block['parameters'];
	$groups;
	if($_GET["init"]==1)
	{
		if(!empty($parameters['groupnodeid']))
		{
			$groups = $parameters['groupnodeid'];
		}
	}
	else
	{
		$groups = json_decode(urldecode($_GET["ingroupid"]));
		//print_r($groups);
	}
	$arr=array();
	if(!empty($groups))
	{
		$arr = Model_Report::getPluginByGroupNode($dbconnection,$groups,$user->getId());
		//print_r($arr);
		foreach($arr as $id => &$elem)
		{
			$common_name = Model_esia::getCommonName($lang, $elem['name'],$elem['name']);
			$elem['name'] = $common_name.' - '.$elem['name'];
			if(in_array($elem['id'], $parameters['plugin']))
			{
				$elem['selected']=1;
			}
		}
	}
	
	if(empty($parameters['plugin']))
	{
		array_unshift($arr,array('id'=>-1,'name'=>$lang['REPORT_PLUGIN_ALL_INCIDENT'],'selected'=>1));
	}
	else
	{
		array_unshift($arr,array('id'=>-1,'name'=>$lang['REPORT_PLUGIN_ALL_INCIDENT']));
	}
	echo json_encode($arr);
	exit(0);
}
elseif($action =="getservice")
{
	if(isset($_GET['nodeid']))
	{
		$tablenodeid = json_decode($_GET['nodeid']);
		$list=array();
		foreach($tablenodeid as $nodeid)
		{
			$node = Model_esia::InstanceNode($dbconnection, $nodeid);
			if($user->getAccess($dbconnection, "device_view",$node->getName())==1)
			{
				$services = Model_esia::getServices($dbconnection,$node->getId());
				foreach ($services as $service)
				{
					$common_name = Model_esia::getCommonName($lang, $service['name'],$service['check_plugin_name']);
					$list[$service['id']]=$node->getName().' > '.$common_name;
				}
			}
		}
		echo json_encode($list);
		exit(0);
	}
}

function getOneGraphService($dbconnection,$end,$interval,$smarty,$param,$lang,$shape)
{
	$values = array();
	$listname = array();
	foreach ($param['nodeid'] as $node)
	{
		$listservice = Model_esia::getServices($dbconnection,$node);
		foreach ($param['serviceid'] as $idService)
		{
			$name=SearchIfContainService($listservice,$idService);
			if($name!=false)
			{
				switch($shape)
				{
					case "donut":
					case "abre":
					case "token":
					case "rectangle":
					case "gauge":
						
						$common_name = Model_esia::getCommonName($lang, $name['service_name'], $name['plugin_name']);
						$result = Model_esia::getTimeErrorAvailability($dbconnection,$node,$idService,$end,$interval);
						$result = eliminateErreurAvaibility($result,$param['calcunknown'],$param['calcwarning'],$param['calccritical']);
						$val = $val + $result['ok']['percent'];
						
						array_push($listname , $name['device_name']." : ".$common_name);
					break;
					case "graph":
						$common_name = Model_esia::getCommonName($lang, $name['service_name'], $name['plugin_name']);
						$pourcent = getAvailabilityList($dbconnection,$node,$idService,$end,$interval);
						foreach ($pourcent as $key => $valpourcent)
						{
								$values[$key] = $values[$key]+$valpourcent;
						}
						array_push($listname , $name['device_name']." : ".$common_name);
						
					break;
				}
				
			}
		}
	}
	switch($shape)
	{
		case "donut":
			$donut_array = array();
			$result['title'] = implode(" & ",$listname);
			$result['ok']['percent'] = $val/count($param['serviceid']);
			$remaining = 100-$result['ok']['percent'];
			$availability = number_format($result['ok']['percent'],2);
			$not_availability = number_format($remaining,2);
			$result['value'] = array('OK' => $availability, 'NOT' => $not_availability);
			$result['rand'] = rand();
			array_push($donut_array,$result);
			$smarty->assign('donuts',$donut_array);
			break;
		
		case "abre":
			$abre_array = array();
			$result['state'] = $state;
			$result['title'] = implode(" & ",$listname);
			$result['rand'] = rand();			
			array_push($abre_array,$result);
			$smarty->assign('abres',$abre_array);
			break;
		
		case "token":
		case "rectangle":
			$token_array = array();
			$state=returnState($result['ok']['percent'],$param);
			$result['title'] = implode(" & ",$listname);
			$result['state'] = $state;
			if($shape=="token")
			{
				$result['radius'] = "50%";
			}
			else
			{
				$result['radius'] = "5px";
			}
			array_push($token_array,$result);
			$smarty->assign('tokens',$token_array);
			break;
		
		case "gauge":
			$gauge_array = array();
			$result['title'] = implode(" & ",$listname);
			$result['ok']['percent'] = $val/count($param['serviceid']);
			$result['rand'] = rand();
			$result['value'] = number_format($result['ok']['percent'],2);
							
			array_push($gauge_array,$result);
			$smarty->assign('gauges',$gauge_array);
			break;
		
		case "graph":
			$title = implode(" & ",$listname);
			$parsed = array();
			foreach ($values as $key => $valpourcent)
			{
				$parsed[parseAvailabilityDate($key,$interval)] = ($val[$key]+$valpourcent)/count($param['serviceid']);
			}
			$json = GetGraphJson($parsed,$i,$lang,$interval);
			$graphs[] = array('title' => $title,
							'data' => $json,
							'rand' => rand(),
							'interval' => $interval
						);
			$smarty->assign('graphs',$graphs);
			break;
	}
	
	
}
function getAvailabilityList($dbconnection,$node,$service,$end,$interval){
	if( $interval == 1 ) {//One day only
		$date = new DateTime();
		$date->setTime(0,0,0);
		$end_date_ts = $date->getTimestamp();
		$end_date_ts--;
	}
	
	if( $interval == 1 ){
		$avai = Model_esia::getDayAvailability($dbconnection,$node,$service,$end_date_ts);
		
	}
	else{
		$avai = Model_esia::getAvailability($dbconnection,$node,$service,$end,$interval);
	}
	return $avai;
}

function parseAvailabilityDate($key,$interval){
	if( $interval == 1){
		$exp =  explode(' ',$key);
		$day = $exp[0];
		$hour = $exp[1];
		$ret = "$day $hour:00:00";
	}
	else
	{
		$ret = $key." 00:00:00";
	}
	return $ret;
}

function getNodeServicesAvailabilities($dbconnection,$node,$services,$end,$interval){	
	$first = true;
	$jsontable=array();
	foreach($services as $service)
	{
		$avai = getAvailabilityList($dbconnection,$node['id'],$service['id'],$end,$interval);

		if( $first ){
			$first = false;
			foreach ($avai as $time => $value){
				$jsontable['x'][] = parseAvailabilityDate($time,$interval);
			}
		}
		
		foreach ($avai as $time => $value)
		{
			if(is_nan($value))
			{
				$value=0;
			}
			else
			{
				$value=intval($value);
			}
			$jsontable[$service['name']][] = $value;
		}
	}
	return $jsontable;
}


/**
 * @brief fais la difference entre noeud et groupe de noeud et retourne les bons param's
 * @detail retourne un array contenant les paramètres utlisés qu'importe que ce soit un noeud ou groupe de noeud
 * @param PDO $dbconnection
 * @param array $param contient les param du block
 * @retval unknown[][]|NULL[][]
 * @throw void
 */

function nodeOrGroupNode($dbconnection,$param,$userid)
{
	$tab_id_node=array();
	if($param['type']=="noeud")
	{
		foreach($param['nodeid'] as $val)
		{
			$node=Model_esia::InstanceNode($dbconnection,$val);
			$tab_id_node[] = array('id'=>$val,'parent'=>$node->getGroup(),'name'=>$node->getName(),'ip'=>$node->getIPAddress());
		}
	}
	else
	{
		foreach ($param['groupnodeid'] as $groupnode )
		{
			$tab_group_node = Model_esia::getAllNodeofGroup($dbconnection,null,$groupnode);
			//$tab_group_node = Model_esia::getNodeList($dbconnection,null,$groupnode,$t_return = Model_esia::NODE_INSTANCE);
			foreach ($tab_group_node as $node)
			{
			    $tab_id_node[] = array('id'=>$node->getId(),'name'=>$node->getName(), 'parent'=>$node->getGroup(),'idgroup'=>$node->getGroupId(),'ip'=>$node->getIPAddress());
			}
		}   
	}
	return $tab_id_node;
}

/**
 @brief retourne le code d'erreur
 @detail retourne le code d'erreur en fonction des seuils de critique et de warning
 @params integer $resultat contient la valeur de disponibilite du service | noeud
 @params array $param les valeurs des deux seuils
 @retval	0|1|2
 @throw void
 */

function returnState($resultat,$param)	
{
	if($resultat>$param['SeuilCritical'])
	{
		if($resultat>$param['SeuilWarning'])
		{
			return 0; // OK
		}
		else
		{
			return 1; // WARNING
		}
	}
	else
	{
		return 2; // CRITICAL
	}
}

/**
 @brief retourne array contenant service plugin et device name
 @params integer $idser contient l'identifiant d'un service
 @params array $array liste des services
 @retval	false | array $ret contenant 
 @throw void
 */

function SearchIfContainService($array, $idser) 
{
	$ret=array();
	foreach ($array as $Element => $tab_elem)
	{
		if ($tab_elem['id'] == $idser) 
		{
			$ret['plugin_name']=$tab_elem['check_plugin_name'];
			$ret['service_name']=$tab_elem['name'];
			$ret['device_name']=$tab_elem['device_name'];
			$ret['device_type']=$tab_elem['device_type'];			
			return $ret;
		}
	}
	return false;
}

/**
 @brief retourne le code d'erreur de la disponibilite du noeud
 @detail Calcule la moyenne de disponibilite des services du noeud 
 @params $dbconnection permet d'acceder à la base de donnée
 @params array $listservice liste des services
 @params integer $node contient l'identifiant du noeud
 @params date $end contient la date 
 @params interval $interval contient l'interval
 @retval	array $ret contenant la valeur de disponibilite du noeud
 */

function StateAvailability($dbconnection,$listservice,$node,$end,$interval)
{
	$resultat=array();
	$resultat['ok']['percent']=0;
	foreach ($listservice as $Service)
	{
		$tmp=array();					
		$tmp=Model_esia::getTimeErrorAvailability($dbconnection,$node,$Service['id'],$end,$interval);
        
		if($tmp['ok']['percent']<0 || $tmp['ok']['percent']=='NAN')
		{
			$tmp['ok']['percent']=0;
		}
		$resultat['ok']['percent']+=$tmp['ok']['percent'];
		$resultat['warning']['percent']+=$tmp['warning']['percent'];
		$resultat['critical']['percent']+=$tmp['critical']['percent'];
		$resultat['unknown']['percent']+=$tmp['unknown']['percent'];
	}
	$nservices = count($listservice);
	$resultat['ok']['percent']=($resultat['ok']['percent'])/$nservices;
	$resultat['warning']['percent']=($resultat['warning']['percent'])/$nservices;
	$resultat['critical']['percent']=($resultat['critical']['percent'])/$nservices;
	$resultat['unknown']['percent']=($resultat['unknown']['percent'])/$nservices;
	return $resultat;
}

// A renommer
function GetGraphJson($pourcent,$idService,$lang,$interval)
{
	$json = array();
	$json['x'] = array();
	$json[$lang['REPORT_GRAPHE_NAME_ABSCISSE']] = array();
	foreach($pourcent as $key => $value)
	{
		$json['x'][] = $key;
		if($value>0)
		{
			$json[$lang['REPORT_GRAPHE_NAME_ABSCISSE']][]= $value;
		}
		else
		{
			$json[$lang['REPORT_GRAPHE_NAME_ABSCISSE']][]= 0;
		}
	}
	$json=json_encode($json, JSON_PRETTY_PRINT);
	
	return $json;
	
}


function eliminateErreurAvaibility($percent, $inconnu='on',$warning='on',$critical='on')
{
	if(!isset($percent['ok']['nbrsec']))	$percent['ok']['nbrsec']=0;
	if(!isset($percent['ok']['percent']))	$percent['ok']['percent']=0;
	
	if($inconnu !='on' && isset($percent['unknown']))
    {
        $percent['ok']['nbrsec']= $percent['ok']['nbrsec'] + $percent['unknown']['nbrsec'];
        $percent['ok']['percent']= $percent['ok']['percent'] + $percent['unknown']['percent'];
        $percent['unknown']=array('nbrsec'=>0,'percent'=>0);
    }
    if($warning !='on' && isset($percent['warning']))
    {
        $percent['ok']['nbrsec']= $percent['ok']['nbrsec'] + $percent['warning']['nbrsec'];
        $percent['ok']['percent']= $percent['ok']['percent'] + $percent['warning']['percent'];
        $percent['warning']=array('nbrsec'=>0,'percent'=>0);
    }
    if($critical !='on' && isset($percent['critical']))
    {
        $percent['ok']['nbrsec']= $percent['ok']['nbrsec'] + $percent['critical']['nbrsec'];
        $percent['ok']['percent']= $percent['ok']['percent'] + $percent['critical']['percent'];
        $percent['critical']=array('nbrsec'=>0,'percent'=>0);
    }
    if($percent['ok']['percent'] > 100)
    {
        $percent['ok']['percent']=100;
    }
    return $percent;
}
?>
