<?php
use function Convert\bytes;

/*DESCRIPTION: inclus les variables habituelles pour la gestion d'un block et vérifie les droits d'accès
 *APRES l'inclusion du common_block les variables suivantes sont créées:
 *PHP:
 *      $dbconnection objet PDO de connexion à la DB
 *      $webplugin_path chemin d'accès au web plugin de repport (default: /usr/local/esia/public_html/plugin/report/
 *      $lang tableau associatif avec les variables de langue
 *      $action l'action passé dans l'url ou 'view'
 *      $gendate tableau associatif reprenant les paramètres global avec les clés suivantes:
 *               ['start']  timestamps de début
 *               ['end']    timestamps de fin
 *               ['interval'] interval en nombre de jour au format php. voir %a par rapport à la date de début  https://www.php.net/manual/fr/dateinterval.format.php
 *      $block les données du block en DB
 *      $parameters un tableau associatif reprenant les paramètres du block
 * SMARTY
 *      $block les informations du block
 *      $parameter les parametres du block (JSON)
 *      $action l'action passé dans l'url ou 'view'
 */
require_once '/usr/local/esia/public_html/plugin/report/report.conf.php';
require_once REPORT_COMMON_BLOCK;
$params = $block['parameters'];

//UPDATE interface web
if($action=="generate")
{
    $nodes = array();
    if($params['element_type']=='group_node')
    {
        $nodes = Model_esia::getAllNodeofGroup($dbconnection, null, $params['element_dbid']);
    }
    else
    {
        foreach ($params['element_dbid'] as $nodeid)
        {
            try
            {
                $infonode=Model_esia::InstanceNode($dbconnection,$nodeid);
                $nodes[]=$infonode;
            }
            catch(Exception $e)
            {

            }
        }
    }
    $list = array();
    foreach($nodes as &$node)
    {
        $services = Model_esia::getServices($dbconnection, $node->getId());
        foreach($services as &$service)
        {
            if(preg_match('#STORAGE#',$service['check_plugin_name']))
            {
                if($service['real_state'] == 3 )
                {
                    $service['value']['hdd']=null;
                }
              //  echo '<pre>';
              //  print_r($service);
                $common_name = Model_esia::getCommonName($lang,$service['name'],$service['check_plugin_name']);
                $common_name = preg_replace('#^.*\-#','', $common_name);
                $name = $node->getName().'-'.$service['name'];
                $descr = htmlentities($node->getDescription() , ENT_QUOTES);
                $list[$name]=array('nodeid'=>$node->getId(),
                    'name'=>$node->getName().' - '.trim($common_name),
                    'group'=> $node->getGroup(),
                	'description'=>$descr,
                    'ip'=>$node->getIPAddress(),
                    'serviceid'=>$service['id'],
                    'percent_used'=>(int)$service['value']['hdd'],
                    'percent_free'=>(100-$service['value']['hdd']));
            }
        }
    }
    ksort($list);
    
    $smarty->assign('list',$list);
        
    //génération en graphique chart
    if($params['form']=='graphCol')
    {
        $c3data=array("data1");
        $c3headder=array();
        $serviceid = "";
        foreach($list as $line)
        {
            $c3data[]=$line['percent_used'];
            $c3headder[]=$line['name'];
            $serviceid = $line['serviceid'];
        }
        $c3data = json_encode($c3data);
        $c3headder = json_encode($c3headder);
        
        $smarty->assign('c3data',$c3data);
        $smarty->assign('c3header',$c3headder);
        $smarty->assign('serviceid',$serviceid);
        
    }
    
    $smarty->display('/usr/local/esia/public_html/plugin/report/blocks/templates/storage.html');
}
elseif($action=="node")
{
    $nodes = Model_esia::getNodeList($dbconnection,$user->getId(),null,Model_esia::NODE_INSTANCE);
    $list=array();

    foreach($nodes as $node)
    {
        $arr = array('id'=>$node->getId(),'parent_name'=>$node->getGroup().'>'.$node->getName());
        if($params['element_type']=='node')
        {
            if(in_array($node->getId(),$params['element_dbid']))
            {
                $arr['selected']=1;
            }
        }
        $list[]= $arr;
    }
    echo json_encode($list);
}
elseif($action=="group_node")
{
	$parameters = $block['parameters'];
	if(empty($parameters['element_type']))
	{
		$parameters['element_type']='group_node';
	}
	$arr = Model_esia::getGroupDevice($dbconnection,null,$user->getId());
	$list_group_node =array();
	if($parameters['element_type']=='group_node')
	{
		foreach($arr as $group)
		{
			$line = array('id'=>$group['id'],'parent_name'=>$group['fullpath']);
			
			if(in_array($group['id'],$parameters['element_dbid']))
			{
				$line['selected']=1;
			}
			$list_group_node[]=$line;
		}
	}
	echo json_encode($list_group_node);
	
}
elseif($action=="update")
{
    $template_path = $path.'/plugin/report/blocks/templates/';
    $smarty->assign('blockid',$block['id']);
    $smarty->assign('canevas_id',$block['include_canevas_id']);
    if(isset($_POST['blockid'])&&!empty($_POST['blockid']))
    {
    	$block = getPostDefaultParams($block,$_POST);
    	$parameters = $block['parameters'];

        //
        // Forme
    	$parameters['form']=$_POST['form'];
        // Seuil de Warning et Critical
    	$parameters['criticalThreshold']=$_POST['criticalThreshold'];
    	$parameters['warningThreshold']=$_POST['warningThreshold'];

        //Paramètre du tableau
        if( empty($_POST['tab_col_group']) )	$_POST['tab_col_group'] = 'none';
        if( empty($_POST['tab_col_ip']) )	$_POST['tab_col_ip'] = 'none';
        if( empty($_POST['tab_col_descr']) )	$_POST['tab_col_descr'] = 'none';
        $parameters['table']['columnshow']['group']=$_POST['tab_col_group'];
        $parameters['table']['columnshow']['ip']=$_POST['tab_col_ip'];
        $parameters['table']['columnshow']['description']=$_POST['tab_col_descr'];
        //Type d'affichage
        $parameters['element_type']=$_POST['select_type_link'];
        $parameters['element_dbid']=$_POST['elementselect'];

        $paramSave = json_encode($parameters);

        Model_Report::UpdtReportIncludeBlock($dbconnection,$block['id'],$block['include_block_id'],$block['include_canevas_id'],$block['include_position'],$paramSave);
        
        $smarty->assign('l_success',$lang['UPDATE_REPORT_SUCCESS']);
        $block['option']=$parameters;
        $smarty->assign('block',$block);
    }
    if(empty($parameters['element_type']))
    {
    	$parameters['element_type']='group_node';
    }
    //explode pour le formulaire afin de spécifier la taille dans un input type numéric
    assignCommonStyles($smarty,$parameters);
    $smarty->assign('params',$parameters);
    $smarty->assign('action','update');
    $smarty->display($template_path.'storage.html');
}
?>
